use AppleScript version "2.4"
use scripting additions
use framework "Foundation"

global pashua_binary

on set_pashua_path(new_path)
	global pashua_path
	
	tell application "Finder"
		if not (new_path exists) then
			error "New path to Pashua.app does not exist" number 1003
		end if
	end tell
	set pashua_binary to (POSIX path of new_path) & "Contents/MacOS/Pashua"
end set_pashua_path


on display_dialog(config)
	-- Get path to Pashua binary
	set pashua_binary to get_pashua_path()
	
	-- Call with either text or alias
	if class of config is text then
		set pashua_cmd to "echo " & quoted form of config & " | " & quoted form of pashua_binary & " -"
	else if class of config is alias then
		set pashua_cmd to quoted form of pashua_binary & space & quoted form of POSIX path of config
	else
		error "Call this method with either 'text' of 'alias', not with '" & (class of config) & "'" number 1000
	end if
	
	-- Call pashua
	set pashua_res to do shell script pashua_cmd
	
	set result_lines to split_string(pashua_res, return)
	
	-- There was an error in the config
	if (count of result_lines) is 0 then error "It looks like Pashua.app had some problems using the window configuration." number 1001
	
	-- User pressed cancel
	if (count of result_lines) is 1 then error number -128 --user canceled 
	
	-- Everything went fine
	set record_result to ini_to_record(result_lines)
	return record_result
	
end display_dialog


-- Private handlers

to split_string(aString as text, delimiter as text)
	local sourceString, res
	if aString is "" then return {} --special case
	set the sourceList to current application's NSString's stringWithString:aString
	set res to sourceList's componentsSeparatedByString:delimiter
	return res as list
end split_string

--| Parses Pashua's output to a AppleScript record
on ini_to_record(ini_lines as list)
	local result_dictionary, pos, key_string, value_string
	set number_of_lines to count of ini_lines
	set result_dictionary to current application's NSMutableDictionary's dictionaryWithCapacity:number_of_lines
	repeat with text_line in ini_lines
		set pos to offset of "=" in text_line
		set key_string to text 1 thru (pos - 1) of text_line
		if (count of text_line) ≤ pos then
			set value_string to "" --use empty string, because missing value won't show up in record
		else
			set value_string to text (pos + 1) thru (length of text_line) of text_line
		end if
		(result_dictionary's setValue:value_string forKey:key_string)
	end repeat
	return result_dictionary as record
end ini_to_record

on get_pashua_path()
	global pashua_binary
	try
		return pashua_binary
	on error number -2753
		--The variable <pashua_path> is not defined
		try
			return path to resource "Pashua.app:"
		on error number -192
			--A resource wasn’t found.
			repeat with pashua_location in [path to applications folder from user domain, path to applications folder from local domain]
				set app_location to (pashua_location as text) & "Pashua.app:"
				tell application "Finder"
					if alias app_location exists then
						set pashua_binary to (my POSIX path of app_location) & "Contents/MacOS/Pashua"
						return pashua_binary
					end if
				end tell
			end repeat
		end try
		error "Can't locate the path of Pashua.app. Download it from http://www.bluem.net/files/Pashua.dmg and save it in the 'Applications' folder." number 1002
	end try
end get_pashua_path


on run1()
	set t to "# Set window title
*.title = Welcome to Pashua
# Extra text
tekst.type = text
tekst.default = Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
#tekst.height = 276
tekst.width = 310
tekst.x = 340
tekst.y = 400
# Introductory text
txt.type = text
txt.default = Pashua is an application for generating dialog windows from programming languages which lack support for creating native GUIs on Mac OS X. Any information you enter in this example window will be returned to the calling script when you hit “OK”; if you decide to click “Cancel” or press “Esc” instead, no values will be returned.[return][return]This window shows nine of the UI element types that are available. You can find a full list of all GUI elements and their corresponding attributes in the documentation (➔ Help menu) that is included with Pashua.
txt.height = 276
txt.width = 310
txt.x = 340
txt.y = 44
txt.tooltip = This is an element of type “text”
# Add a text field
tf.type = textfield
tf.label = Example textfield
tf.default = Textfield content
tf.width = 310
tf.tooltip = This is an element of type “textfield”
# Add a filesystem browser
ob.type = openbrowser
ob.label = Example filesystem browser (textfield + open panel)
ob.width=310
ob.tooltip = This is an element of type “openbrowser”
# Do some date
dt.label = What's your birthday?
dt.type = date
dt.textual = 0
dt.time = 1
dt.tooltip = Don't be shy, you can pick any year.
# Define radiobuttons
rb.type = radiobutton
rb.label = Example radiobuttons
rb.option = Radiobutton item #1
rb.option = Radiobutton item #2
rb.option = Radiobutton item #3
rb.tooltip = This is an element of type “radiobutton”
# Add a popup menu
pop.type = popup
pop.label = Example popup menu
pop.width = 310
pop.option = Popup menu item #1
pop.option = Popup menu item #2
pop.option = Popup menu item #3
pop.default = Popup menu item #2
pop.tooltip = This is an element of type “popup”
# Add 2 checkboxes
chk.rely = -18
chk.type = checkbox
chk.label = Pashua offers checkboxes, too
chk.tooltip = This is an element of type “checkbox”
chk.default = 1
chk2.type = checkbox
chk2.label = But this one is disabled
chk2.disabled = 1
chk2.tooltip = Another element of type “checkbox”
# Add a cancel button with default label
hb.type = button
hb.label = Help
hb.tooltip = Display some help
cb.type = cancelbutton
cb.tooltip = This is an element of type “cancelbutton”
db.type = defaultbutton
db.tooltip = This is an element of type “defaultbutton” (which is automatically added to each window, if not included in the configuration)
#img.type = image
#img.x = 435
#img.y = 248
#img.maxwidth = 128
#img.tooltip = This is an element of type 'image'
#img.path = /Applications/Pashua.app/Contents/Resources/AppIcon@2.png"
	display_pashua_dialog(t)
end run1

on run {}
	tell application "Finder" to set script_path to (container of container of (path to me)) as text
  set example_path to ((script_path as text) & "tmp:Example-dialog.pashua")
  display alert example_path
	set example_dialog to alias example_path
	display_pashua_dialog(example_dialog)
end run
